@@ -37,7 +37,7 @@ my($graph) = GraphViz2 -> new
 	 global => {directed => 1},
 	 graph  => {rankdir => 'TB'},
 	 logger => $logger,
-	 node   => {color => 'darkblue', shape => 'oval'},
+	 node   => {color => 'blue', shape => 'oval'},
 	);
 my($g)      = GraphViz2::Parse::RecDescent -> new(graph => $graph);
 my $grammar = slurp(File::Spec -> catfile('t', 'sample.recdescent.1.dat') );
